Method: Mailchimp::Users#invites

Defined in:
lib/mailchimp/api.rb

#invitesArray

Retrieve the list of pending users invitations have been sent for.

Returns:

  • (Array)

    structs for each invitation, including:

    • String

      email the email address the invitation was sent to

    • String

      role the role that will be assigned if they accept

    • String

      sent_at the time the invitation was sent. this will change if it’s resent.

    • String

      expiration the expiration time for the invitation. this will change if it’s resent.

    • String

      msg the welcome message included with the invitation



206
207
208
209
# File 'lib/mailchimp/api.rb', line 206

def invites()
    _params = {}
    return @master.call 'users/invites', _params
end