Method: Mailchimp::Reports#opened
- Defined in:
- lib/mailchimp/api.rb
#opened(cid, opts = []) ⇒ Array
Retrieve the list of email addresses that opened a given campaign with how many times they opened
1931 1932 1933 1934 |
# File 'lib/mailchimp/api.rb', line 1931 def opened(cid, opts=[]) _params = {:cid => cid, :opts => opts} return @master.call 'reports/opened', _params end |